ArgumentCallbacks<T> class

Mutable collection of ArgumentCallback instances, itself an ArgumentCallback.

Additions and removals happening during a single call invocation do not change who gets a callback until the next such invocation.

Optimized for the singleton case.

Constructors

ArgumentCallbacks()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection is empty.
no setter
isNotEmpty → bool
Whether this collection is non-empty.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(ArgumentCallback<T> callback) → void
Adds a callback to this collection.
call(T argument) → void
Callback method. Invokes the corresponding method on each callback in this collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(ArgumentCallback<T> callback) → void
Removes a callback from this collection.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited