AssetBitmap class

A bitmap specified by a name and optional package.

Inheritance

Constructors

AssetBitmap({required String name, String? package})
Provides an asset name with name and optionally a package.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the asset backing the bitmap.
final
package → String?
Optional package of the asset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Convert the object to a Json format.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited