CameraUpdateAnimationConfiguration class

Defines an animation configuration for camera updates.

Annotations

Constructors

CameraUpdateAnimationConfiguration({Duration? duration})
Creates a immutable animation configuration for camera updates.
const

Properties

duration → Duration?
The duration of the animation.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited