CameraUpdateScrollBy class

Defines a camera scroll by a certain delta.

Inheritance

Constructors

CameraUpdateScrollBy(double dx, double dy)
Creates a camera scroll.
const

Properties

dx → double
Scroll delta x.
final
dy → double
Scroll delta y.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateType → CameraUpdateType
Indicates which type of camera update this instance represents.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited