CameraUpdateZoomBy class

Defines a relative camera zoom.

Inheritance

Constructors

CameraUpdateZoomBy(double amount, [Offset? focus])
Creates a relative camera zoom.
const

Properties

amount → double
Change in camera zoom amount.
final
focus → Offset?
Optional point around which the zoom is focused.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateType → CameraUpdateType
Indicates which type of camera update this instance represents.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited