CircleUpdates class

Circle update events to be applied to the AMap.

Used in AMapController when the map is updated.

Inheritance

Constructors

CircleUpdates.from(Set<Circle> previous, Set<Circle> current)
Computes CircleUpdates given previous and current Circles.

Properties

circleIdsToRemove → Set<CircleId>
Set of CircleIds to be removed in this update.
no setter
circlesToAdd → Set<Circle>
Set of Circles to be added in this update.
no setter
circlesToChange → Set<Circle>
Set of Circles to be changed in this update.
no setter
hashCode → int
The hash code for this object.
no setterinherited
objectIdsToRemove → Set<MapsObjectId<Circle>>
Set of objects to be removed in this update.
no setterinherited
objectName → String
The name of the objects being updated, for use in serialization.
finalinherited
objectsToAdd → Set<Circle>
Set of objects to be added in this update.
no setterinherited
objectsToChange → Set<Circle>
Set of objects to be changed in this update.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited