Cluster class

A cluster containing multiple markers.

Annotations

Constructors

Cluster(ClusterManagerId clusterManagerId, List<MarkerId> markerIds, {required LatLng position, required LatLngBounds bounds})
Creates a cluster with its location LatLng, bounds LatLngBounds, and list of MarkerIds in the cluster.
const

Properties

bounds → LatLngBounds
The bounds containing all cluster markers.
final
clusterManagerId → ClusterManagerId
ID of the ClusterManager of the cluster.
final
count → int
Returns the number of markers in the cluster.
no setter
hashCode → int
The hash code for this object.
no setteroverride
markerIds → List<MarkerId>
List of MarkerIds in the cluster.
final
position → LatLng
Cluster marker location.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override