ClusterManagerUpdates class

ClusterManager update events to be applied to the AMap.

Used in AMapController when the map is updated.

Inheritance

Constructors

ClusterManagerUpdates.from(Set<ClusterManager> previous, Set<ClusterManager> current)
Computes ClusterManagerUpdates given previous and current ClusterManagers.

Properties

clusterManagerIdsToRemove → Set<ClusterManagerId>
Set of ClusterManagerIds to be removed in this update.
no setter
clusterManagersToAdd → Set<ClusterManager>
Set of Clusters to be added in this update.
no setter
clusterManagersToChange → Set<ClusterManager>
Set of Clusters to be changed in this update.
no setter
hashCode → int
The hash code for this object.
no setterinherited
objectIdsToRemove → Set<MapsObjectId<ClusterManager>>
Set of objects to be removed in this update.
no setterinherited
objectName → String
The name of the objects being updated, for use in serialization.
finalinherited
objectsToAdd → Set<ClusterManager>
Set of objects to be added in this update.
no setterinherited
objectsToChange → Set<ClusterManager>
Set of objects to be changed in this update.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited