HeatmapGradientColor class

A Color with a startPoint for use in a HeatmapGradient.

Annotations

Constructors

HeatmapGradientColor(Color color, double startPoint)
Creates a new HeatmapGradientColor object.
const

Properties

color → Color
The color for this portion of the gradient.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPoint → double
The start point of this color.
final

Methods

clone() → HeatmapGradientColor
Creates a new HeatmapGradientColor object whose values are the same as this instance.
copyWith({Color? colorParam, double? startPointParam}) → HeatmapGradientColor
Creates a new HeatmapGradientColor object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override