InfoWindow class

Text labels for a Marker info window.

Annotations

Constructors

InfoWindow({String? title, String? snippet, Offset anchor = const Offset(0.5, 0.0), VoidCallback? onTap})
Creates an immutable representation of a label on for Marker.
const

Properties

anchor → Offset
The icon image point that will be the anchor of the info window when displayed.
final
hashCode → int
The hash code for this object.
no setteroverride
onTap → VoidCallback?
onTap callback for this InfoWindow.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet → String?
Additional text displayed below the title.
final
title → String?
Text displayed in an info window when the user taps the marker.
final

Methods

copyWith({String? titleParam, String? snippetParam, Offset? anchorParam, VoidCallback? onTapParam}) → InfoWindow
Creates a new InfoWindow object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

noText → const InfoWindow
Text labels specifying that no text is to be displayed.