MapConfiguration class

Configuration options for the user interface.

Annotations

Constructors

MapConfiguration({bool? compassEnabled, bool? mapToolbarEnabled, CameraTargetBounds? cameraTargetBounds, MapType? mapType, MinMaxZoomPreference? minMaxZoomPreference, bool? rotateGesturesEnabled, bool? scrollGesturesEnabled, bool? tiltGesturesEnabled, bool? fortyFiveDegreeImageryEnabled, bool? trackCameraPosition, bool? zoomControlsEnabled, bool? zoomGesturesEnabled, bool? liteModeEnabled, bool? myLocationEnabled, bool? myLocationButtonEnabled, EdgeInsets? padding, bool? indoorViewEnabled, bool? trafficEnabled, bool? buildingsEnabled, String? cloudMapId, String? style})
Creates a new configuration instance with the given options.
const

Properties

buildingsEnabled → bool?
True if 3D building display should be enabled.
final
cameraTargetBounds → CameraTargetBounds?
The bounds to display.
final
cloudMapId → String?
Identifier that's associated with a specific cloud-based map style.
final
compassEnabled → bool?
True if the compass UI should be shown.
final
fortyFiveDegreeImageryEnabled → bool?
True if 45 degree imagery should be enabled.
final
hashCode → int
The hash code for this object.
no setteroverride
indoorViewEnabled → bool?
True if indoor map views should be enabled.
final
isEmpty → bool
True if no options are set.
no setter
liteModeEnabled → bool?
True if the map should use Lite Mode, showing a limited-interactivity bitmap, on supported platforms.
final
mapToolbarEnabled → bool?
True if the map toolbar should be shown.
final
mapType → MapType?
The type of the map.
final
minMaxZoomPreference → MinMaxZoomPreference?
The preferred zoom range.
final
myLocationButtonEnabled → bool?
True if the control to jump to the current location should be displayed.
final
myLocationEnabled → bool?
True if the current location should be tracked and displayed.
final
padding → EdgeInsets?
The padding for the map display.
final
rotateGesturesEnabled → bool?
True if rotate gestures should be enabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollGesturesEnabled → bool?
True if scroll gestures should be enabled.
final
style → String?
Locally configured JSON style.
final
tiltGesturesEnabled → bool?
True if tilt gestures should be enabled.
final
trackCameraPosition → bool?
True if camera position changes should trigger notifications.
final
trafficEnabled → bool?
True if the traffic overlay should be enabled.
final
zoomControlsEnabled → bool?
True if zoom controls should be displayed.
final
zoomGesturesEnabled → bool?
True if zoom gestures should be enabled.
final

Methods

applyDiff(MapConfiguration diff) → MapConfiguration
Returns a copy of this instance with any non-null settings form diff replacing the previous values.
diffFrom(MapConfiguration other) → MapConfiguration
Returns a new options object containing only the values of this instance that are different from other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override