MapLongPressEvent class

An event fired when a Map is long pressed.

Inheritance

Constructors

MapLongPressEvent(int mapId, LatLng position)
Build an MapTap Event triggered from the map represented by mapId.

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapId → int
The ID of the Map this event is associated to.
finalinherited
position → LatLng
The position where this event happened.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → void
The value wrapped by this event
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited