MapObjects class

A container object for all the types of maps objects.

This is intended for use as a parameter in platform interface methods, to allow adding new object types to existing methods.

Annotations

Constructors

MapObjects({Set<Marker> markers = const <Marker>{}, Set<Polygon> polygons = const <Polygon>{}, Set<Polyline> polylines = const <Polyline>{}, Set<Circle> circles = const <Circle>{}, Set<Heatmap> heatmaps = const <Heatmap>{}, Set<TileOverlay> tileOverlays = const <TileOverlay>{}, Set<ClusterManager> clusterManagers = const <ClusterManager>{}, Set<GroundOverlay> groundOverlays = const <GroundOverlay>{}})
Creates a new set of map objects with all the given object types.
const

Properties

circles → Set<Circle>
final
clusterManagers → Set<ClusterManager>
final
groundOverlays → Set<GroundOverlay>
final
hashCode → int
The hash code for this object.
no setterinherited
heatmaps → Set<Heatmap>
final
markers → Set<Marker>
final
polygons → Set<Polygon>
final
polylines → Set<Polyline>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileOverlays → Set<TileOverlay>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited