MapStyleException class

Exception when a map style is invalid or was unable to be set.

See also: setStyle on AMapController for why this exception might be thrown.

Implemented types

Constructors

MapStyleException(String cause)
Default constructor for MapStyleException.
const

Properties

cause → String
The reason GoogleMapController.setStyle would throw this exception.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited