MapsObject<T> class abstract

A common interface for maps types.

Implementers

Constructors

MapsObject()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapsId → MapsObjectId<T>
A identifier for this object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → T
Returns a duplicate of this object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited