MapsObjectUpdates<T extends MapsObject<T>> class

Update specification for a set of objects.

Implementers
Annotations

Constructors

MapsObjectUpdates.from(Set<T> previous, Set<T> current, {required String objectName})
Computes updates given previous and current object sets.

Properties

hashCode → int
The hash code for this object.
no setteroverride
objectIdsToRemove → Set<MapsObjectId<T>>
Set of objects to be removed in this update.
no setter
objectName → String
The name of the objects being updated, for use in serialization.
final
objectsToAdd → Set<T>
Set of objects to be added in this update.
no setter
objectsToChange → Set<T>
Set of objects to be changed in this update.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override