PatternItem class

Item used in the stroke pattern for a Polyline.

Implementers
Annotations

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PatternItemType
The type of rendering used for an item in a pattern.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

dash(double length) → PatternItem
A dash used in the stroke pattern for a Polyline.
gap(double length) → PatternItem
A gap used in the stroke pattern for a Polyline.

Constants

dot → const PatternItem
A dot used in the stroke pattern for a Polyline.