PolygonUpdates class

Polygon update events to be applied to the AMap.

Used in AMapController when the map is updated.

Inheritance

Constructors

PolygonUpdates.from(Set<Polygon> previous, Set<Polygon> current)
Computes PolygonUpdates given previous and current Polygons.

Properties

hashCode → int
The hash code for this object.
no setterinherited
objectIdsToRemove → Set<MapsObjectId<Polygon>>
Set of objects to be removed in this update.
no setterinherited
objectName → String
The name of the objects being updated, for use in serialization.
finalinherited
objectsToAdd → Set<Polygon>
Set of objects to be added in this update.
no setterinherited
objectsToChange → Set<Polygon>
Set of objects to be changed in this update.
no setterinherited
polygonIdsToRemove → Set<PolygonId>
Set of PolygonIds to be removed in this update.
no setter
polygonsToAdd → Set<Polygon>
Set of Polygons to be added in this update.
no setter
polygonsToChange → Set<Polygon>
Set of Polygons to be changed in this update.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited