PolylineUpdates class

Polyline update events to be applied to the AMap.

Used in AMapController when the map is updated.

Inheritance

Constructors

PolylineUpdates.from(Set<Polyline> previous, Set<Polyline> current)
Computes PolylineUpdates given previous and current Polylines.

Properties

hashCode → int
The hash code for this object.
no setterinherited
objectIdsToRemove → Set<MapsObjectId<Polyline>>
Set of objects to be removed in this update.
no setterinherited
objectName → String
The name of the objects being updated, for use in serialization.
finalinherited
objectsToAdd → Set<Polyline>
Set of objects to be added in this update.
no setterinherited
objectsToChange → Set<Polyline>
Set of objects to be changed in this update.
no setterinherited
polylineIdsToRemove → Set<PolylineId>
Set of PolylineIds to be removed in this update.
no setter
polylinesToAdd → Set<Polyline>
Set of Polylines to be added in this update.
no setter
polylinesToChange → Set<Polyline>
Set of Polylines to be changed in this update.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited