Tile class

Contains information about a Tile that is returned by a TileProvider.

Annotations

Constructors

Tile(int width, int height, Uint8List? data)
Creates an immutable representation of a Tile to draw by TileProvider.
const

Properties

data → Uint8List?
A byte array containing the image data.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the image encoded by data in logical pixels.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
The width of the image encoded by data in logical pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited